==> leanix-synclog-sdk-java-0.5.1-sources.jar: net/leanix/synclog/api/models/ApiError.java <==
/*
* The MIT License (MIT)	 
*
* Copyright (c) 2014 LeanIX GmbH
* 
* Permission is hereby granted, free of charge, to any person obtaining a copy of
* this software and associated documentation files (the "Software"), to deal in
* the Software without restriction, including without limitation the rights to
* use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
* the Software, and to permit persons to whom the Software is furnished to do so,
* subject to the following conditions:
* 
* The above copyright notice and this permission notice shall be included in all
* copies or substantial portions of the Software.
* 
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
* IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
* FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
* COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
* IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
* CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

package net.leanix.synclog.api.models;

import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import java.io.*;
import java.util.*;
public class ApiError
{
	private String value = null;
	private List<String> messages = new ArrayList<String>();
	@JsonProperty("value")
	public String getValue()
	{
		return value;
	}
	
	@JsonProperty("value")
	public void setValue(String value)
	{
		this.value = value;
	}

	@JsonProperty("messages")
	public List<String> getMessages()
	{
		return messages;
	}
	
	@JsonProperty("messages")
	public void setMessages(List<String> messages)
	{
		this.messages = messages;
	}

	@Override
	public String toString()
	{
		StringBuilder sb = new StringBuilder();
		sb.append("class ApiError {\n");
		sb.append("  value: ").append(value).append("\n");
		sb.append("  messages: ").append(messages).append("\n");
		sb.append("}\n");
		return sb.toString();
	}

    /**
     * Setter for unknown properties.
     *
     * @param key
     * @param value
     */
    @JsonAnySetter
    public void handleUnknown(String key, Object value)
    {
    }
}

==> leanix-synclog-sdk-java-0.6.0-sources.jar: net/leanix/synclog/api/models/ApiError.java <==
/*
* The MIT License (MIT)	 
*
* Copyright (c) 2014 LeanIX GmbH
* 
* Permission is hereby granted, free of charge, to any person obtaining a copy of
* this software and associated documentation files (the "Software"), to deal in
* the Software without restriction, including without limitation the rights to
* use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
* the Software, and to permit persons to whom the Software is furnished to do so,
* subject to the following conditions:
* 
* The above copyright notice and this permission notice shall be included in all
* copies or substantial portions of the Software.
* 
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
* IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
* FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
* COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
* IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
* CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

package net.leanix.synclog.api.models;

import com.fasterxml.jackson.annotation.JsonProperty;
import java.io.*;

import java.util.*;
public class ApiError implements Serializable
{
	private String value = null;
	private List<String> messages = new ArrayList<String>();
	@JsonProperty("value")
	public String getValue()
	{
		return value;
	}
	
	@JsonProperty("value")
	public void setValue(String value)
	{
		this.value = value;
	}

	@JsonProperty("messages")
	public List<String> getMessages()
	{
		return messages;
	}
	
	@JsonProperty("messages")
	public void setMessages(List<String> messages)
	{
		this.messages = messages;
	}

	@Override
	public String toString()
	{
		StringBuilder sb = new StringBuilder();
		sb.append("class ApiError {\n");
		sb.append("  value: ").append(value).append("\n");
		sb.append("  messages: ").append(messages).append("\n");
		sb.append("}\n");
		return sb.toString();
	}
}
